Units - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Units

WeeWX offers three different unit systems:

The standard unit systems used within WeeWX
Name | Encoded value | Note
US | 0x01 | U.S. Customary
METRICWX | 0x11 | Metric, with rain related measurements in mm and speeds in m/s
METRIC | 0x10 | Metric, with rain related measurements in cm and speeds in km/hr

The table below lists all the unit groups, their members, which units are options for the group, and what the defaults are for each standard unit system.

Unit groups, members and options
Group | Members | Unit options | US | METRICWX | METRIC
group_altitude | altitude cloudbase | foot meter | foot | meter | meter
group_amp |  | amp | amp | amp | amp
group_angle |  | degree_angle radian | degree_angle | degree_angle | degree_angle
group_boolean |  | boolean | boolean | boolean | boolean
group_concentration | no2 pm1_0 pm2_5 pm10_0 | microgram_per_meter_cubed | microgram_per_meter_cubed | microgram_per_meter_cubed | microgram_per_meter_cubed
group_count | leafWet1 leafWet2 lightning_disturber_count lightning_noise_count lightning_strike_count | count | count | count | count
group_data |  | byte bit | byte | byte | byte
group_db | noise | dB | dB | dB | dB
group_delta_time | daySunshineDur rainDur sunshineDurDoc | second minute hour day | second | second | second
group_degree_day | cooldeg heatdeg growdeg | degree_F_day degree_C_day | degree_F_day | degree_C_day | degree_C_day
group_direction | gustdir vecdir windDir windGustDir | degree_compass | degree_compass | degree_compass | degree_compass
group_distance | windrun lightning_distance | mile km | mile | km | km
group_energy |  | kilowatt_hour mega_joule watt_hour watt_second | watt_hour | watt_hour | watt_hour
group_energy2 |  | kilowatt_hour watt_hour watt_second | watt_second | watt_second | watt_second
group_fraction | co co2 nh3 o3 pb so2 | ppm | ppm | ppm | ppm
group_frequency |  | hertz | hertz | hertz | hertz
group_illuminance | illuminance | lux | lux | lux | lux
group_interval | interval | minute | minute | minute | minute
group_length |  | inch cm | inch | cm | cm
group_moisture | soilMoist1 soilMoist2 soilMoist3 soilMoist4 | centibar | centibar | centibar | centibar
group_percent | cloudcover extraHumid1 extraHumid2 inHumidity outHumidity pop rxCheckPercent snowMoisture | percent | percent | percent | percent
group_power |  | kilowatt watt | watt | watt | watt
group_pressure | barometer altimeter pressure | inHg mbar hPa kPa | inHg | mbar | mbar
group_pressurerate | barometerRate altimeterRate pressureRate | inHg_per_hour mbar_per_hour hPa_per_hour kPa_per_hour | inHg_per_hour | mbar_per_hour | mbar_per_hour
group_radiation | maxSolarRad radiation | watt_per_meter_squared | watt_per_meter_squared | watt_per_meter_squared | watt_per_meter_squared
group_rain | rain ET hail snowDepth snowRate | inch cm mm | inch | mm | cm
group_rainrate | rainRate hailRate | inch_per_hour cm_per_hour mm_per_hour | inch_per_hour | mm_per_hour | cm_per_hour
group_speed | wind windGust windSpeed windgustvec windvec | mile_per_hour km_per_hour knot meter_per_second beaufort | mile_per_hour | meter_per_second | km_per_hour
group_speed2 | rms vecavg | mile_per_hour2 km_per_hour2 knot2 meter_per_second2 | mile_per_hour2 | meter_per_second2 | km_per_hour2
group_temperature | appTemp dewpoint extraTemp1 extraTemp2 extraTemp3 heatindex heatingTemp humidex inTemp leafTemp1 leafTemp2 outTemp soilTemp1 soilTemp2 soilTemp3 soilTemp4 windchill THSW | degree_C degree_F degree_E degree_K | degree_F | degree_C | degree_C
group_time | dateTime | unix_epoch dublin_jd | unix_epoch | unix_epoch | unix_epoch
group_uv | UV | uv_index | uv_index | uv_index | uv_index
group_volt | consBatteryVoltage heatingVoltage referenceVoltage supplyVoltage | volt | volt | volt | volt
group_volume |  | cubic_foot gallon liter | gallon | liter | liter
group_NONE | NONE | NONE | NONE | NONE | NONE